@@ -1,28 +1,16 @@
-/* This file is part of the KDE project
- *
- * Copyright (C) 2002-2004 George Staikos <staikos@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
+/*
+    This file is part of the KDE project
+
+    SPDX-FileCopyrightText: 2002-2004 George Staikos <staikos@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef _KWALLET_H
 #define _KWALLET_H
 
-#include <QtCore/QStringList>
-#include <QtCore/QObject>
+#include <QObject>
+#include <QStringList>
 #include <qwindowdefs.h> // krazy:exclude=includes (for WId)
 
 #include <kwallet_export.h>
@@ -47,7 +35,6 @@
 
 namespace KWallet
 {
-
 /**
  * KDE Wallet
  *
@@ -75,12 +62,18 @@ protected:
     Wallet(const Wallet &);
 
 public:
-    enum EntryType { Unknown = 0, Password, Stream, Map, Unused = 0xffff };
+    enum EntryType {
+        Unknown = 0,
+        Password,
+        Stream,
+        Map,
+        Unused = 0xffff,
+    };
 
     /**
      *  Destroy a KWallet object.  Closes the wallet.
      */
-    virtual ~Wallet();
+    ~Wallet() override;
 
     /**
      *  List all the wallets available.
@@ -130,7 +123,12 @@ public:
      */
     static bool disconnectApplication(const QString &wallet, const QString &app);
 
-    enum OpenType { Synchronous = 0, Asynchronous, Path, OpenTypeUnused = 0xff };
+    enum OpenType {
+        Synchronous = 0,
+        Asynchronous,
+        Path,
+        OpenTypeUnused = 0xff,
+    };
 
     /**
      *  Open the wallet @p name.  The user will be prompted to
@@ -157,7 +155,7 @@ public:
     /**
      *  List the applications that are using the wallet @p wallet.
      *  @param wallet The wallet to query.
-     *  @return Returns a list of all DCOP application IDs using
+     *  @return Returns a list of all D-Bus application IDs using
      *          the wallet.
      */
     static QStringList users(const QString &wallet);
@@ -327,6 +325,7 @@ public:
      */
     virtual int readPassword(const QString &key, QString &value);
 
+#if KWALLET_ENABLE_DEPRECATED_SINCE(5, 72)
     /**
      *  Read the entries matching @p key from the current folder.
      *  The entry format is unknown except that it is either a
@@ -337,9 +336,14 @@ public:
      *  @param value A buffer to fill with the value.  The key in
      *               the map is the entry key.
      *  @return Returns 0 on success, non-zero on error.
+     *
+     *  @deprecated Since 5.72, use entriesList(bool *)
      */
+    KWALLET_DEPRECATED_VERSION(5, 72, "Use entriesList(bool *)")
     int readEntryList(const QString &key, QMap<QString, QByteArray> &value);
+#endif
 
+#if KWALLET_ENABLE_DEPRECATED_SINCE(5, 72)
     /**
      *  Read the map entry @p key from the current folder.
      *  @param key The key of the entry to read.  Wildcards
@@ -349,9 +353,14 @@ public:
      *  @return Returns 0 on success, non-zero on error.  Will
      *          return an error if the key was not originally
      *          written as a map.
+     *
+     *  @deprecated Since 5.72, use mapList(bool *)
      */
-    int readMapList(const QString &key, QMap<QString, QMap<QString, QString> > &value);
+    KWALLET_DEPRECATED_VERSION(5, 72, "Use mapList(bool *)")
+    int readMapList(const QString &key, QMap<QString, QMap<QString, QString>> &value);
+#endif
 
+#if KWALLET_ENABLE_DEPRECATED_SINCE(5, 72)
     /**
      *  Read the password entry @p key from the current folder.
      *  @param key The key of the entry to read.  Wildcards
@@ -361,8 +370,54 @@ public:
      *  @return Returns 0 on success, non-zero on error.  Will
      *          return an error if the key was not originally
      *          written as a password.
+     *
+     *  @deprecated Since 5.72, use passwordList(bool *)
      */
+    KWALLET_DEPRECATED_VERSION(5, 72, "Use passwordList(bool *)")
     int readPasswordList(const QString &key, QMap<QString, QString> &value);
+#endif
+
+    /**
+     *  Get a list of all the entries in the current folder. The entry
+     *  format is unknown except that it is either a QByteArray or a
+     *  QDataStream, which effectively means that it could be anything.
+     *
+     *  @param ok if not nullptr, the object this parameter points to will be set
+     *            to true to indicate success or false otherwise
+     *  @return a map of key/value pairs where the key in the map is the entry key
+     *
+     *  @since 5.72
+     */
+    QMap<QString, QByteArray> entriesList(bool *ok) const;
+
+    /**
+     *  Get a list of all the maps in the current folder.
+     *
+     *  @param ok if not nullptr, the object this parameter points to will be set
+     *            to true to indicate success or false otherwise. Note that if any
+     *            of the keys was not originally written as a map, the object will
+     *            be set to false
+     *
+     *  @return a map of key/value pairs where the key in the map is the entry key
+     *
+     *  @since 5.72
+     */
+    QMap<QString, QMap<QString, QString>> mapList(bool *ok) const;
+
+    /**
+     *  Get a list of all the passwords in the current folder, which can
+     *  be used to populate a list view in a password manager.
+     *
+     *  @param ok if not nullptr, the object this parameter points to will be
+     *            set to true to indicate success or false otherwise. Note that
+     *            the object will be set to false if any of the keys was not
+     *            originally written as a password
+     *
+     *  @return a map of key/value pairs, where the key in the map is the entry key
+     *
+     *  @since 5.72
+     */
+    QMap<QString, QString> passwordList(bool *ok) const;
 
     /**
      *  Write @p key = @p value as a binary entry to the current
@@ -446,8 +501,7 @@ public:
      *  @return Returns true if the key does NOT exist in the
      *  wallet, or the folder or wallet does not exist.
      */
-    static bool keyDoesNotExist(const QString &wallet, const QString &folder,
-                                const QString &key);
+    static bool keyDoesNotExist(const QString &wallet, const QString &folder, const QString &key);
 
     /**
      * Determine if the KWallet API is using the KSecretsService infrastructure
@@ -488,39 +542,39 @@ Q_SIGNALS:
 private Q_SLOTS:
     /**
      *  @internal
-     *  DBUS slot for signals emitted by the wallet service.
+     *  D-Bus slot for signals emitted by the wallet service.
      */
     void slotWalletClosed(int handle);
 
     /**
      *  @internal
-     *  DBUS slot for signals emitted by the wallet service.
+     *  D-Bus slot for signals emitted by the wallet service.
      */
     void slotFolderUpdated(const QString &wallet, const QString &folder);
 
     /**
      *  @internal
-     *  DBUS slot for signals emitted by the wallet service.
+     *  D-Bus slot for signals emitted by the wallet service.
      */
     void slotFolderListUpdated(const QString &wallet);
 
     /**
      *  @internal
-     *  DBUS slot for signals emitted by the wallet service.
+     *  D-Bus slot for signals emitted by the wallet service.
      */
     void slotApplicationDisconnected(const QString &wallet, const QString &application);
 
     /**
      *  @internal
      *  Callback for kwalletd
-     *  @param tId identifer for the open transaction
+     *  @param tId identifier for the open transaction
      *  @param handle the wallet's handle
      */
     void walletAsyncOpened(int tId, int handle);
 
     /**
      *  @internal
-     *  DBUS error slot.
+     *  D-Bus error slot.
      */
     void emitWalletAsyncOpenError();
 
@@ -556,4 +610,3 @@ protected:
 }
 
 #endif //_KWALLET_H
-
